
#
# This R script plots the ancestral chromosome numbers estimated 
# by a ChromoSSE RevBayes analysis.
#
# Install the RevGadgets R package from:
# https://github.com/revbayes/RevGadgets
#

library(ggplot2)
library(RevGadgets)

# plot the ancestral states tree generated by RevBayes
p = plot_ancestral_states(tree_file="output/BiChroM_final.tree", 
                          summary_statistic="MAPChromosome", 
                          include_start_states=FALSE, 
                          tip_label_size=2.75, 
                          tip_label_offset=0.002,
                          tip_label_italics=TRUE,
                          node_label_size=2,
                          node_label_nudge_x=0.0005,
                          xlim_visible=c(0, 0.14),
                          shoulder_label_size=2,
                          alpha=.3,
                          show_posterior_legend=TRUE,
                          show_state_legend=FALSE,
                          title="An Example BiChroM Analysis")


# using ggtree and ggplot2 functions we can now add all sorts of details
# to our figure:

# annotate some of the clades
p = p + geom_cladelabel(node=60, label="Isotrema", align=TRUE, offset=0.043, size=1.5)
p = p + geom_cladelabel(node=36, label="Aristolochia", align=TRUE, offset=0.043, size=1.5)


# write pdf
print(p)
ggsave("output/BiChroM.pdf")

