
#
# This R script plots the ancestral chromosome numbers estimated 
# by a ChromoSSE RevBayes analysis.
#
# Install the RevGadgets R package from:
# https://github.com/revbayes/RevGadgets
#

library(ggplot2)
library(RevGadgets)

# plot the ancestral states tree generated by RevBayes
p = plot_ancestral_states(tree_file="output/ChromEvol_simple_final.tree", 
                          summary_statistic="MAPChromosome", 
                          include_start_states=FALSE, 
                          tip_label_size=3, 
                          tip_label_offset=0.002,
                          tip_label_italics=TRUE,
                          node_label_size=2.5,
                          node_label_nudge_x=0.0005,
                          xlim_visible=c(0, 0.105),
                          shoulder_label_size=2,
                          alpha=.3,
                          show_posterior_legend=TRUE,
                          title="A Basic ChromEvol Analysis")


# using ggtree and ggplot2 functions we can now add all sorts of details
# to our figure:

# annotate some of the clades
p = p + geom_cladelabel(node=60, label="Isotrema", align=TRUE, offset=0.02, size=2)
p = p + geom_cladelabel(node=36, label="Aristolochia", align=TRUE, offset=0.02, size=2)


# write pdf
print(p)
ggsave("output/ChromEvol_simple.pdf")

